@@ -1,8 +1,9 @@
 import sys
 import os
 import json
+import subprocess
 
-__version__ = "0.0.3"
+__version__ = "0.0.6"
 userhome = os.environ["HOME"]
 confpath = ".config" + os.sep + "proj.py.conf"
 fullpath = userhome + os.sep + confpath
@@ -45,6 +46,8 @@ def main():
             if(proj["name"] == sys.argv[1]):
                 # then cd to this dir
                 os.chdir(proj["dir"])
+                subprocess.call(['cd', proj["dir"]])
+                break
     save_conf(conf)
 
 
